<h1 align="center">arie</h1>
<h3 align="center">summary</h3>

<p align="center">
<a href="https://travis-ci.org/aluttik/arie"><img alt="Build status" src="https://img.shields.io/travis/aluttik/arie/master.svg"></a>
<a href="https://pypi.org/project/arie/"><img alt="PyPI version" src="https://img.shields.io/pypi/v/arie.svg"></a>
<a href="https://pypi.org/project/arie"><img alt="Supported Python versions" src="https://img.shields.io/pypi/pyversions/arie.svg"></a>
<a href="https://pypi.org/project/arie"><img alt="License: Apache 2.0" src="https://img.shields.io/pypi/l/arie.svg"></a>
<a href="https://github.com/aluttik/arie"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
</p>

## Installation

    pip install arie

